package iguanaman.hungeroverhaul.module.vanilla;

import iguanaman.hungeroverhaul.common.config.Config;
import iguanaman.hungeroverhaul.library.RecipeRemover;
import iguanaman.hungeroverhaul.module.bonemeal.BonemealModule;
import iguanaman.hungeroverhaul.module.bonemeal.modification.BonemealModification;
import iguanaman.hungeroverhaul.module.food.FoodModifier;
import iguanaman.hungeroverhaul.module.growth.PlantGrowthModule;
import iguanaman.hungeroverhaul.module.growth.modification.PlantGrowthModification;
import net.minecraft.block.BlockBeetroot;
import net.minecraft.block.BlockCactus;
import net.minecraft.block.BlockCarrot;
import net.minecraft.block.BlockCocoa;
import net.minecraft.block.BlockCrops;
import net.minecraft.block.BlockNetherWart;
import net.minecraft.block.BlockPotato;
import net.minecraft.block.BlockReed;
import net.minecraft.block.BlockSapling;
import net.minecraft.block.BlockStem;
import net.minecraft.block.state.IBlockState;
import net.minecraft.init.Items;
import net.minecraft.item.ItemStack;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.EnumDifficulty;
import net.minecraft.world.World;
import net.minecraftforge.common.BiomeDictionary.Type;
import net.minecraftforge.fml.common.registry.GameRegistry;
import net.minecraftforge.oredict.ShapelessOreRecipe;
import squeek.applecore.api.food.FoodValues;

public class VanillaModule
{
    public static void init()
    {
        if (Config.addSeedsCraftingRecipe)
        {
            GameRegistry.addRecipe(new ShapelessOreRecipe(Items.field_151014_N, Items.field_151015_O));
        }

        /*
         * Food values
         */
        if (Config.modifyFoodValues && Config.useHOFoodValues)
        {
            FoodModifier.setModifiedFoodValues(Items.field_151034_e, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151025_P, new FoodValues(3, 0.2F));
            FoodModifier.setModifiedFoodValues(Items.field_151147_al, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151157_am, new FoodValues(2, 0.15F));
            FoodModifier.setModifiedFoodValues(Items.field_151115_aP, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_179566_aV, new FoodValues(2, 0.1F));
            FoodModifier.setModifiedFoodValues(Items.field_151106_aX, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151127_ba, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151082_bd, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151083_be, new FoodValues(2, 0.15F));
            FoodModifier.setModifiedFoodValues(Items.field_151076_bf, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151077_bg, new FoodValues(2, 0.15F));
            FoodModifier.setModifiedFoodValues(Items.field_151078_bh, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151168_bH, new FoodValues(2, 0.15F));
            FoodModifier.setModifiedFoodValues(Items.field_151170_bI, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151158_bO, new FoodValues(3, 0.15F));
            FoodModifier.setModifiedFoodValues(Items.field_151009_A, new FoodValues(2, 0.1F));
            FoodModifier.setModifiedFoodValues(Items.field_151172_bF, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_151174_bG, new FoodValues(1, 0.05F));

            FoodModifier.setModifiedFoodValues(Items.field_179561_bm, new FoodValues(1, 0.05F));
            FoodModifier.setModifiedFoodValues(Items.field_179557_bn, new FoodValues(2, 0.1F));
        }

        /*
         * Plant growth
         */
        PlantGrowthModification cropGrowthModification = new PlantGrowthModification().setNeedsSunlight(true).setGrowthTickProbability(Config.cropRegrowthMultiplier).setBiomeGrowthModifier(Type.FOREST, 1).setBiomeGrowthModifier(Type.PLAINS, 1);
        PlantGrowthModule.registerPlantGrowthModifier(BlockCrops.class, cropGrowthModification);
        PlantGrowthModule.registerPlantGrowthModifier(BlockCarrot.class, cropGrowthModification);
        PlantGrowthModule.registerPlantGrowthModifier(BlockPotato.class, cropGrowthModification);
        PlantGrowthModule.registerPlantGrowthModifier(BlockBeetroot.class, cropGrowthModification);

        PlantGrowthModification reedGrowthModification = new PlantGrowthModification().setNeedsSunlight(true).setGrowthTickProbability(Config.sugarcaneRegrowthMultiplier).setBiomeGrowthModifier(Type.JUNGLE, 1).setBiomeGrowthModifier(Type.SWAMP, 1).setWrongBiomeMultiplier(Config.wrongBiomeRegrowthMultiplierSugarcane);
        PlantGrowthModule.registerPlantGrowthModifier(BlockReed.class, reedGrowthModification);

        PlantGrowthModification stemGrowthModification = new PlantGrowthModification().setNeedsSunlight(true).setGrowthTickProbability(Config.cropRegrowthMultiplier).setBiomeGrowthModifier(Type.JUNGLE, 1).setBiomeGrowthModifier(Type.SWAMP, 1);
        PlantGrowthModule.registerPlantGrowthModifier(BlockStem.class, stemGrowthModification);

        PlantGrowthModification cocoaGrowthModification = new PlantGrowthModification().setNeedsSunlight(false).setGrowthTickProbability(Config.cocoaRegrowthMultiplier).setBiomeGrowthModifier(Type.JUNGLE, 1);
        PlantGrowthModule.registerPlantGrowthModifier(BlockCocoa.class, cocoaGrowthModification);

        PlantGrowthModification cactusGrowthModification = new PlantGrowthModification().setNeedsSunlight(false).setGrowthTickProbability(Config.cactusRegrowthMultiplier).setBiomeGrowthModifier(Type.SANDY, 1);
        PlantGrowthModule.registerPlantGrowthModifier(BlockCactus.class, cactusGrowthModification);

        PlantGrowthModification saplingGrowthModification = new PlantGrowthModification().setGrowthTickProbability(Config.saplingRegrowthMultiplier);
        PlantGrowthModule.registerPlantGrowthModifier(BlockSapling.class, saplingGrowthModification);

        PlantGrowthModification netherWartGrowthModification = new PlantGrowthModification().setNeedsSunlight(false).setGrowthTickProbability(Config.netherWartRegrowthMultiplier).setBiomeGrowthModifier(Type.NETHER, 1);
        PlantGrowthModule.registerPlantGrowthModifier(BlockNetherWart.class, netherWartGrowthModification);

        /*
         * Bonemeal
         */
        BonemealModification cropBonemealModification = new BonemealModification()
        {
            @Override
            public IBlockState getNewState(World world, BlockPos pos, IBlockState currentState)
            {
                if (currentState.func_177230_c() instanceof BlockCrops)
                {
                    int currentMeta = currentState.func_177229_b(BlockCrops.field_176488_a);
                    int metaIncrease = 1;

                    if (Config.difficultyScalingBoneMeal && world.func_175659_aa().func_151525_a() < EnumDifficulty.EASY.func_151525_a())
                    {
                        metaIncrease = world.field_73012_v.nextInt(3);
                    }

                    return currentState.func_177226_a(BlockCrops.field_176488_a, Math.min(currentMeta + metaIncrease, 7));
                }
                else
                {
                    return currentState;
                }
            }
        };
        BonemealModule.registerBonemealModifier(BlockCrops.class, cropBonemealModification);
        BonemealModule.registerBonemealModifier(BlockCarrot.class, cropBonemealModification);
        BonemealModule.registerBonemealModifier(BlockPotato.class, cropBonemealModification);

        BonemealModification beetrootBonemealModification = new BonemealModification()
        {
            @Override
            public IBlockState getNewState(World world, BlockPos pos, IBlockState currentState)
            {
                if (currentState.func_177230_c() instanceof BlockBeetroot)
                {
                    int currentMeta = currentState.func_177229_b(BlockBeetroot.field_185531_a);
                    int metaIncrease = 1;

                    if (Config.difficultyScalingBoneMeal && world.func_175659_aa().func_151525_a() < EnumDifficulty.EASY.func_151525_a())
                    {
                        metaIncrease = world.field_73012_v.nextInt(2);
                    }

                    return currentState.func_177226_a(BlockBeetroot.field_185531_a, Math.min(currentMeta + metaIncrease, 3));
                }
                else
                {
                    return currentState;
                }
            }
        };
        BonemealModule.registerBonemealModifier(BlockBeetroot.class, beetrootBonemealModification);
    }

    public static void postInit()
    {
        if (Config.removeHoeRecipes)
        {
            RecipeRemover.removeAnyRecipe(new ItemStack(Items.field_151017_I));
            RecipeRemover.removeAnyRecipe(new ItemStack(Items.field_151018_J));
        }
    }
}
